/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (close_small)
#endif
#ifdef __GNUC__
static const guint8 close_small[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 close_small[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (196) */
  "\0\0\0\334"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (28) */
  "\0\0\0\34"
  /* width (7) */
  "\0\0\0\7"
  /* height (7) */
  "\0\0\0\7"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377"
  "\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\377\0\0\0\377"};


